pub struct ReadOptions {
pub snapshot: Option<u64>,
pub fill_cache: bool,
pub verify_checksums: bool,
pub readahead_size: usize,
pub total_order_seek: bool,
pub pin_data: bool,
}Expand description
Options for read operations.
Fields
snapshot: Option<u64>If set, reads will use this snapshot sequence number.
fill_cache: boolWhether to fill the block cache for this read. Default: true.
verify_checksums: boolWhether to verify checksums on reads. Default: false.
readahead_size: usizeReadahead size hint in bytes for sequential iteration. 0 = auto. Default: 0.
RocksDB equivalent: readahead_size.
total_order_seek: boolIf true, ignore prefix bloom filters and do a total order seek. Default: false.
RocksDB equivalent: total_order_seek.
pin_data: boolIf true, pin data blocks in memory during iteration. Default: false.
RocksDB equivalent: pin_data.